SQLiteConnection class

Constructors

SQLiteConnection({required String path})

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
The full sqlite file path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

backupDatabase(String backupPath) → Future<File>
Backs up the current SQLite database to a specified file path.
batch() → Future<Batch>
count(ISQLiteItem item) → Future<int>
createTable(ISQLiteItem item) → Future<void>
delete(ISQLiteItem item) → Future<int>
deleteAll(List<ISQLiteItem> items) → Future<int>
deleteRecords(ISQLiteItem item) → Future<void>
dispose() → Future<void>
dropTable(ISQLiteItem item) → Future<void>
first(ISQLiteItem item) → Future<ISQLiteItem?>
getOpenDatabase() → Future<Database>
groupBy(ISQLiteItem item, List<String> columns, String groupByColumnName, {String? orderByColumn, bool distinct = true}) → Future<List<ISQLiteItem>>
Groups the results of a database query by a specified column and returns the results as a list of ISQLiteItem instances.
hasItems(ISQLiteItem item) → Future<bool>
index(ISQLiteItem item, int index) → Future<ISQLiteItem?>
insert(ISQLiteItem item) → Future<int>
insertAll(List<ISQLiteItem> items) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paginate(ISQLiteItem item, int limit, int offset) → Future<List<ISQLiteItem>>
Retrieves a paginated list of items from the SQLite database.
random(ISQLiteItem item, int count) → Future<List<ISQLiteItem>>
Performs a case-insensitive search in a specified column of an SQLite table.
searchColumns(ISQLiteItem item, List<String> columnNames, String query, {int? limit}) → Future<List<ISQLiteItem>>
tableColumns(String tableName, {Database? db}) → Future<List<String>>
tableExists(String tableName) → Future<bool>
toList(ISQLiteItem item) → Future<List<ISQLiteItem>>
toListWhereColumnHasValue(ISQLiteItem item, String columnName, dynamic columnValueOf, {int? limit}) → Future<List<ISQLiteItem>>
toListWhereColumnHasValueMatch(ISQLiteItem item, String columnName, dynamic columnValueOf) → Future<List<ISQLiteItem>>
Retrieves a list of items that match the exact condition for the specified column. This method does not account for case differences; it performs a case-sensitive match.
toListWhereMapContains(ISQLiteItem item, Map<String, dynamic> columnNameAndValues, {int? limit}) → Future<List<ISQLiteItem>>
toListWhereMapMatch(ISQLiteItem item, Map<String, dynamic> columnValues) → Future<List<ISQLiteItem>>
toListWhereValuesAre(ISQLiteItem item, String columnName, List<String> columnValueList) → Future<List<ISQLiteItem>>
Fetches multiple items from the database based on a specific column and a list of values.
toString() → String
A string representation of this object.
inherited
update(ISQLiteItem item) → Future<void>
updateAll(List<ISQLiteItem> items) → Future<int>
vacuum(ISQLiteItem item) → Future<void>
whereColumnHasValue(ISQLiteItem item, String columnName, dynamic columnValueOf) → Future<ISQLiteItem?>
whereMapMatch(ISQLiteItem item, Map<String, dynamic> columnValues) → Future<ISQLiteItem?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

areDatabaseTablesExist(String filePath, List<String> tables) → Future<bool>
getDatabase(String sqliteFilePath, {int version = 1}) → Future<Database>
getTableInfo(String filePath, String tableName) → Future<List<Map<String, dynamic>>?>
initDatabaseLib() → bool
isValidDatabaseFile(String filePath) → Future<bool>