sqlite_flutter_pcl library

Classes

Batch
A batch is used to perform multiple operation as a single atomic unit. A Batch object can be acquired by calling Database.batch. It provides methods for adding operation. None of the operation will be executed (or visible locally) until commit() is called.
ByteBuffer
A sequence of bytes underlying a typed data object.
ByteData
A fixed-length, random-access sequence of bytes that also provides random and unaligned access to the fixed-width integers and floating point numbers represented by those bytes.
BytesBuilder
Builds a list of bytes, allowing bytes and lists of bytes to be added at the end.
CompressionOptions
Options controlling compression in a WebSocket.
ConnectionTask<S>
A cancelable connection attempt.
ContentType
A MIME/IANA media type used as the value of the HttpHeaders.contentTypeHeader header.
Context
An instantiable class for manipulating paths. Unlike the top-level functions, this lets you explicitly select what platform the paths will use.
Representation of a cookie. For cookies received by the server as Cookie header values only name and value properties will be set. When building a cookie for the 'set-cookie' header in the server and when receiving cookies in the client as 'set-cookie' headers all fields can be used.
Database
Database to send sql commands, created during openDatabase
DatabaseExecutor
Common API for Database and Transaction to execute SQL commands
DatabaseFactory
Basic databases operations
Datagram
A data packet received by a RawDatagramSocket.
Directory
A reference to a directory (or folder) on the file system.
Endian
Endianness of number representation.
File
A reference to a file on the file system.
FileLock
Type of lock when requesting a lock on a file.
FileMode
The modes in which a File can be opened.
FileStat
The result of calling the POSIX stat() function on a file system object.
FileSystemCreateEvent
File system event for newly created file system objects.
FileSystemDeleteEvent
File system event for deletion of file system objects.
FileSystemEntity
The common superclass of File, Directory, and Link.
FileSystemEntityType
The type of an entity on the file system, such as a file, directory, or link.
FileSystemEvent
Base event class emitted by FileSystemEntity.watch.
FileSystemModifyEvent
File system event for modifications of file system objects.
FileSystemMoveEvent
File system event for moving of file system objects.
Float32List
A fixed-length list of IEEE 754 single-precision binary floating-point numbers that is viewable as a TypedData.
Float32x4
Four 32-bit floating point values.
Float32x4List
A fixed-length list of Float32x4 numbers that is viewable as a TypedData.
Float64List
A fixed-length list of IEEE 754 double-precision binary floating-point numbers that is viewable as a TypedData.
Float64x2
Float64x2 immutable value type and operations.
Float64x2List
A fixed-length list of Float64x2 numbers that is viewable as a TypedData.
GZipCodec
The GZipCodec encodes raw bytes to GZip compressed bytes and decodes GZip compressed bytes to raw bytes.
HeaderValue
Representation of a header value in the form:
HttpClient
An HTTP client for communicating with an HTTP server.
HttpClientBasicCredentials
Represents credentials for basic authentication.
HttpClientBearerCredentials
Represents credentials for bearer token authentication.
HttpClientCredentials
Represents credentials for authentication in HttpClient.
HttpClientDigestCredentials
Represents credentials for digest authentication.
HttpClientRequest
HTTP request for a client connection.
HttpClientResponse
HTTP response for a client connection.
HttpConnectionInfo
Information about an HttpRequest, HttpResponse, HttpClientRequest, or HttpClientResponse connection.
HttpConnectionsInfo
Summary statistics about an HttpServers current socket connections.
HttpDate
Utility functions for working with dates with HTTP specific date formats.
HttpHeaders
Headers for HTTP requests and responses.
HttpOverrides
This class facilitates overriding HttpClient with a mock implementation. It should be extended by another class in client code with overrides that construct a mock implementation. The implementation in this base class defaults to the actual HttpClient implementation. For example:
HttpRequest
A server-side object that contains the content of and information about an HTTP request.
HttpResponse
An HTTP response, which returns the headers and data from the server to the client in response to an HTTP request.
HttpServer
A server that delivers content, such as web pages, using the HTTP protocol.
HttpSession
The HttpRequest.session of an HttpRequest.
HttpStatus
HTTP status codes. Exported in dart:io and dart:html.
Int16List
A fixed-length list of 16-bit signed integers that is viewable as a TypedData.
Int32List
A fixed-length list of 32-bit signed integers that is viewable as a TypedData.
Int32x4
Int32x4 and operations.
Int32x4List
A fixed-length list of Int32x4 numbers that is viewable as a TypedData.
Int64List
A fixed-length list of 64-bit signed integers that is viewable as a TypedData.
Int8List
A fixed-length list of 8-bit signed integers.
InternetAddress
An internet address or a Unix domain address.
InternetAddressType
The type, or address family, of an InternetAddress.
IOOverrides
Facilities for overriding various APIs of dart:io with mock implementations.
IOSink
A combined byte and text output.
ISQLiteItem
ISQLiteItemExtended
References to filesystem links.
NetworkInterface
A NetworkInterface represents an active network interface on the current system. It contains a list of InternetAddresses that are bound to the interface.
OpenDatabaseOptions
Options for opening the database see openDatabase for details
PathMap<V>
A map whose keys are paths, compared using p.equals and p.hash.
PathSet
A set containing paths, compared using p.equals and p.hash.
Pipe
An anonymous pipe that can be used to send data in a single direction i.e. data written to write can be read using read.
Platform
Information about the environment in which the current program is running.
Process
The means to execute a program.
ProcessInfo
Methods for retrieving information about the current process.
ProcessResult
The result of running a non-interactive process started with Process.run or Process.runSync.
ProcessSignal
On Posix systems, ProcessSignal is used to send a specific signal to a child process, see Process.kill.
ProcessStartMode
Modes for running a new process.
QueryCursor
Cursor for query by page cursor.
RandomAccessFile
Random access to the data in a file.
RawDatagramSocket
An unbuffered interface to a UDP socket.
RawSecureServerSocket
A server socket providing a stream of low-level RawSecureSockets.
RawSecureSocket
RawSecureSocket provides a secure (SSL or TLS) network connection.
RawServerSocket
A listening socket.
RawSocket
A TCP connection.
RawSocketEvent
Events for the RawDatagramSocket, RawSecureSocket, and RawSocket.
RawSocketOption
The RawSocketOption is used as a parameter to Socket.setRawOption and RawSocket.setRawOption to customize the behaviour of the underlying socket.
RawSynchronousSocket
A low-level class for communicating synchronously over a TCP socket.
RawZLibFilter
The RawZLibFilter class provides a low-level interface to zlib.
ReadPipe
The "read" end of an Pipe created by Pipe.create.
RedirectInfo
Redirect information.
ResourceHandle
A wrapper around OS resource handle so it can be passed via Socket as part of SocketMessage.
SameSite
Cookie cross-site availability configuration.
SecureServerSocket
A server socket, providing a stream of high-level Sockets.
SecureSocket
A TCP socket using TLS and SSL.
SecurityContext
The object containing the certificates to trust when making a secure client connection, and the certificate chain and private key to serve from a secure server.
ServerSocket
A listening socket.
Socket
A TCP connection between two sockets.
SocketControlMessage
Control message part of the SocketMessage received by a call to RawSocket.readMessage.
SocketDirection
The SocketDirection is used as a parameter to Socket.close and RawSocket.close to close a socket in the specified direction(s).
SocketMessage
A socket message received by a RawDatagramSocket.
SocketOption
An option for a socket which is configured using Socket.setOption.
Sqflite
sqflite plugin
SqfliteDarwin
Darwin specific implementation.
SqfliteOptions
internal options.
SqflitePlugin
sqflite Plugin registration.
SQLiteConnection
SQLiteItemBatch
Stdin
The standard input stream of the process.
StdioType
The type of object a standard IO stream can be attached to.
Stdout
An IOSink connected to either the standard out or error of the process.
Style
An enum type describing a "flavor" of path.
SystemEncoding
The system encoding is the current code page on Windows and UTF-8 on Linux and Mac.
TlsProtocolVersion
A Transport Layer Security (TLS) version.
Transaction
Database transaction to use during a transaction
TypedData
A typed view of a sequence of bytes.
TypedDataList<E>
A TypedData fixed-length List-view on the bytes of buffer.
Uint16List
A fixed-length list of 16-bit unsigned integers that is viewable as a TypedData.
Uint32List
A fixed-length list of 32-bit unsigned integers that is viewable as a TypedData.
Uint64List
A fixed-length list of 64-bit unsigned integers that is viewable as a TypedData.
Uint8ClampedList
A fixed-length list of 8-bit unsigned integers.
Uint8List
A fixed-length list of 8-bit unsigned integers.
WebSocket
A two-way HTTP communication object for client or server applications.
WebSocketStatus
WebSocket status codes used when closing a WebSocket connection.
WebSocketTransformer
The WebSocketTransformer provides the ability to upgrade a HttpRequest to a WebSocket connection. It supports both upgrading a single HttpRequest and upgrading a stream of HttpRequests.
WritePipe
The "write" end of an Pipe created by Pipe.create.
X509Certificate
X509Certificate represents an SSL certificate, with accessors to get the fields of the certificate.
ZLibCodec
The ZLibCodec encodes raw bytes to ZLib compressed bytes and decodes ZLib compressed bytes to raw bytes.
ZLibDecoder
The ZLibDecoder is used by ZLibCodec and GZipCodec to decompress data.
ZLibEncoder
The ZLibEncoder encoder is used by ZLibCodec and GZipCodec to compress data.
ZLibOption
Exposes ZLib options for input parameters.

Enums

ConflictAlgorithm
Insert/Update conflict resolver
HttpClientResponseCompressionState
Enum that specifies the compression state of the byte stream of an HttpClientResponse.
StorageDirectory
Corresponds to constants defined in Androids android.os.Environment class.

Extensions

DatabaseFactoryLoggerDebugExt on DatabaseFactory
Debug extension for Logger.
SqfliteDatabaseAndroidExt on Database
Android only API
SqfliteDatabaseExecutorExt on DatabaseExecutor
Helpers
SqfliteDatabaseExt on Database
Set the journal mode
SqfliteDatabaseFactoryDebug on DatabaseFactory
Debug extension

Constants

gzip → const GZipCodec
An instance of the default implementation of the GZipCodec.
inMemoryDatabasePath → const String
Special database name opened in memory
systemEncoding → const SystemEncoding
The current system encoding.
zlib → const ZLibCodec
An instance of the default implementation of the ZLibCodec.

Properties

context Context
The system path context.
final
current String
Gets the path to the current working directory.
no setter
databaseFactory DatabaseFactory
sqflite Default factory.
getter/setter pair
databaseFactoryFfi DatabaseFactory
The database factory to use for ffi.
no setter
databaseFactoryFfiNoIsolate DatabaseFactory
The database factory to use for ffi without isolate
no setter
databaseFactoryOrNull DatabaseFactory?
Default database factory.
getter/setter pair
databaseFactorySqflitePlugin DatabaseFactory
Default factory that uses the plugin.
no setter
disablePathProviderPlatformOverride bool
no getter
exitCode int
Get the global exit code for the Dart VM.
getter/setter pair
onDatabaseDowngradeDelete OnDatabaseVersionChangeFn
Downgrading will delete the database and open it again.
final
pid int
Returns the PID of the current process.
no setter
posix Context
A default context for manipulating POSIX paths.
final
separator String
Gets the path separator for the current platform. This is \ on Windows and / on other platforms (including the browser).
no setter
sqfliteLogLevelNone int
No logs
final
sqfliteLogLevelSql int
Log native sql commands
final
sqfliteLogLevelVerbose int
Log native verbose
final
stderr Stdout
The standard output stream of errors written by this program.
no setter
stdin Stdin
The standard input stream of data read by this program.
no setter
stdout Stdout
The standard output stream of data written by this program.
no setter
style Style
Returns the Style of the current context.
no setter
url Context
A default context for manipulating URLs.
final
windows Context
A default context for manipulating Windows paths.
final

Functions

absolute(String part1, [String? part2, String? part3, String? part4, String? part5, String? part6, String? part7, String? part8, String? part9, String? part10, String? part11, String? part12, String? part13, String? part14, String? part15]) String
Returns a new path with the given path parts appended to current.
basename(String path) String
Gets the part of path after the last separator.
basenameWithoutExtension(String path) String
Gets the part of path after the last separator, and without any trailing file extension.
canonicalize(String path) String
Canonicalizes path.
createDatabaseFactoryFfi({SqfliteFfiInit? ffiInit, bool noIsolate = false}) DatabaseFactory
Creates an FFI database factory. Optionally the FFIInit function can be provided if you want to override some behavior with the sqlite3 dynamic library opening. This function should be either a top level function or a static function. Prefer the use of the databaseFactoryFfi getter if you don't need this functionality.
databaseExists(String path) Future<bool>
Check if a database exists at a given path.
deleteDatabase(String path) Future<void>
Delete the database at the given path.
dirname(String path) String
Gets the part of path before the last separator.
equals(String path1, String path2) bool
Returns true if path1 points to the same location as path2, and false otherwise.
exit(int code) → Never
Exit the Dart VM process immediately with the given exit code.
extension(String path, [int level = 1]) String
Gets the file extension of path: the portion of basename from the last . to the end (including the . itself).
fromUri(Object? uri) String
Returns the path represented by uri, which may be a String or a Uri.
getApplicationCacheDirectory() Future<Directory>
Path to a directory where the application may place application-specific cache files.
getApplicationDocumentsDirectory() Future<Directory>
Path to a directory where the application may place data that is user-generated, or that cannot otherwise be recreated by your application.
getApplicationSupportDirectory() Future<Directory>
Path to a directory where the application may place application support files.
getDatabasesPath() Future<String>
Get the default databases location.
getDownloadsDirectory() Future<Directory?>
Path to the directory where downloaded files can be stored.
getExternalCacheDirectories() Future<List<Directory>?>
Paths to directories where application specific cache data can be stored externally.
getExternalStorageDirectories({StorageDirectory? type}) Future<List<Directory>?>
Paths to directories where application specific data can be stored externally.
getExternalStorageDirectory() Future<Directory?>
Path to a directory where the application may access top level storage.
getLibraryDirectory() Future<Directory>
Path to the directory where application can store files that are persistent, backed up, and not visible to the user, such as sqlite.db.
getTemporaryDirectory() Future<Directory>
Path to the temporary directory on the device that is not backed up and is suitable for storing caches of downloaded files.
hash(String path) int
Returns a hash code for path such that, if equals returns true for two paths, their hash codes are the same.
isAbsolute(String path) bool
Returns true if path is an absolute path and false if it is a relative path.
isRelative(String path) bool
Returns true if path is a relative path and false if it is absolute. On POSIX systems, absolute paths start with a / (forward slash). On Windows, an absolute path starts with \\, or a drive letter followed by :/ or :\.
isRootRelative(String path) bool
Returns true if path is a root-relative path and false if it's not.
isWithin(String parent, String child) bool
Returns true if child is a path beneath parent, and false otherwise.
join(String part1, [String? part2, String? part3, String? part4, String? part5, String? part6, String? part7, String? part8, String? part9, String? part10, String? part11, String? part12, String? part13, String? part14, String? part15, String? part16]) String
Joins the given path parts into a single path using the current platform's separator. Example:
joinAll(Iterable<String> parts) String
Joins the given path parts into a single path using the current platform's separator. Example:
normalize(String path) String
Normalizes path, simplifying it by handling .., and ., and removing redundant path separators whenever possible.
onDatabaseVersionChangeError(Database db, int oldVersion, int newVersion) Future<void>
to specify during openDatabase for OpenDatabaseOptions.onDowngrade Downgrading will always fail
openDatabase(String path, {int? version, OnDatabaseConfigureFn? onConfigure, OnDatabaseCreateFn? onCreate, OnDatabaseVersionChangeFn? onUpgrade, OnDatabaseVersionChangeFn? onDowngrade, OnDatabaseOpenFn? onOpen, bool? readOnly = false, bool? singleInstance = true}) Future<Database>
Open the database at a given path
openReadOnlyDatabase(String path, {bool? singleInstance = true}) Future<Database>
Open the database at a given path in read only mode
prettyUri(Object? uri) String
Returns a terse, human-readable representation of uri.
relative(String path, {String? from}) String
Attempts to convert path to an equivalent relative path from the current directory.
rootPrefix(String path) String
Returns the root of path, if it's absolute, or the empty string if it's relative.
setExtension(String path, String extension) String
Returns path with the trailing extension set to extension.
sleep(Duration duration) → void
Sleep for the duration specified in duration.
split(String path) List<String>
Splits path into its components using the current platform's separator.
sqfliteFfiInit() → void
Optional. Initialize ffi loader.
stdioType(dynamic object) StdioType
Whether a stream is attached to a file, pipe, terminal, or something else.
toUri(String path) Uri
Returns the URI that represents path.
withoutExtension(String path) String
Removes a trailing extension from the last part of path.

Typedefs

BadCertificateCallback = bool Function(X509Certificate cr, String host, int port)
OnDatabaseConfigureFn = FutureOr<void> Function(Database db)
Prototype of the function called before calling OpenDatabaseOptions.onCreate/OpenDatabaseOptions.onUpgrade/OpenDatabaseOptions.onOpen when the database is open.
OnDatabaseCreateFn = FutureOr<void> Function(Database db, int version)
Prototype of the function called when the database is created.
OnDatabaseOpenFn = FutureOr<void> Function(Database db)
Prototype of the function called when the database is open.
OnDatabaseVersionChangeFn = FutureOr<void> Function(Database db, int oldVersion, int newVersion)
Prototype of the function called when the version has changed.
SqfliteFfiInit = void Function()
Signature responsible for overriding the SQLite dynamic library to use.

Exceptions / Errors

CertificateException
An exception that happens in the handshake phase of establishing a secure network connection, when looking up or verifying a certificate.
DatabaseException
Wrap sqlite native exception
FileSystemException
Exception thrown when a file operation fails.
HandshakeException
An exception that happens in the handshake phase of establishing a secure network connection.
HttpException
IOException
Base class for all IO related exceptions.
MissingPlatformDirectoryException
An exception thrown when a directory that should always be available on the current platform cannot be obtained.
OSError
An Exception holding information about an error from the operating system.
PathAccessException
Exception thrown when a file operation fails because the necessary access rights are not available.
PathException
An exception class that's thrown when a path operation is unable to be computed accurately.
PathExistsException
Exception thrown when a file operation fails because the target path already exists.
PathNotFoundException
Exception thrown when a file operation fails because a file or directory does not exist.
ProcessException
RedirectException
SignalException
SocketException
Exception thrown when a socket operation fails.
StdinException
Exception thrown by some operations of Stdin
StdoutException
Exception thrown by some operations of Stdout
TlsException
A secure networking exception caused by a failure in the TLS/SSL protocol.
WebSocketException